@@ -7,12 +7,10 @@ import json
 import requests
 
 # Partial imports
-from marshmallow import ValidationError
 from requests.auth import HTTPBasicAuth
 from requests.exceptions import ConnectionError, HTTPError
 
 # Imports from modules
-from cornflow_client import SchemaManager
 from cornflow_client.constants import AirflowError
 
 
@@ -65,8 +63,12 @@ class Airflow(object):
         url = f"{self.url}/dags/{dag_name}/updateTaskInstancesState"
         return self.request_headers_auth(method="POST", url=url, json=payload)
 
-    def run_dag(self, execution_id, dag_name="solve_model_dag", checks_only=False):
+    def run_dag(
+        self, execution_id, dag_name="solve_model_dag", checks_only=False, case_id=None
+    ):
         conf = dict(exec_id=execution_id, checks_only=checks_only)
+        if case_id is not None:
+            conf["case_id"] = case_id
         payload = dict(conf=conf)
         return self.consume_dag_run(dag_name, payload=payload, method="POST")
 
@@ -142,18 +144,3 @@ class Airflow(object):
     def get_model_dags(self, method="GET"):
         url = f"{self.url}/dags?tags=model"
         return self.request_headers_auth(method=method, url=url)
-
-
-def get_schema(config, dag_name, schema="instance"):
-    """
-    Gets a schema by name from airflow server. We use the variable api.
-    We transform the jsonschema into a marshmallow class
-
-    """
-    af_client = Airflow.from_config(config)
-    if not af_client.is_alive():
-        raise AirflowError(error="Airflow is not accessible")
-
-    schema_json = af_client.get_one_schema(dag_name, schema)
-    manager = SchemaManager(schema_json)
-    return manager.jsonschema_to_flask()
