@@ -61,7 +61,6 @@ class TestABC(unittest.TestCase):
     def test_check_data(self):
         inst_check, sol_check, log = GoodApp().check(dict(number=""), dict())
         self.assertIsInstance(inst_check, dict)
-        self.assertFalse(inst_check.get("is_infeasible", True))
         self.assertIsInstance(sol_check, dict)
         self.assertIsInstance(log, dict)
         self.assertEqual(log.get('status'), "Optimal")
@@ -69,9 +68,10 @@ class TestABC(unittest.TestCase):
 
 class GoodInstanceClass(InstanceCore):
     schema = get_empty_schema(dict(number=dict(type="number")))
+    schema_checks = get_empty_schema()
 
     def check(self) -> dict:
-        return dict(is_infeasible=False)
+        return dict()
 
 
 class BadInstanceClass(InstanceCore):
@@ -91,6 +91,8 @@ class BadSolutionClass(SolutionCore):
 
 
 class GoodExperiment(ExperimentCore):
+    schema_checks = get_empty_schema()
+
     def solve(self, options: dict):
         return dict(sol_status=1, status=1)
 
